==> MuSE-0.6.5.tar.gz: MuSE-0.6.5/generic.h <==
/* MuSE - Multiple Streaming Engine
 * Copyright (C) 2000-2002 Denis Roio aka jaromil <jaromil@dyne.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __GENERIC_H
#define __GENERIC_H

/* soundcard tweaks */
#define SAMPLE_RATE 44100 // 44100
#define BUF_SIZE 4608 // 1152 (mp3 default framesize) *2 (16bit) *2 (stereo)
#define PROCBUF_SIZE 8192 // mixer process buffers size
#define FRAGSIZE 0x000c // 4096 bytes
#define FRAGCOUNT 0x7fff // no limit

/* mp3 channels - the standard interface can't be changed from here
   uhm... you'd better not touch this, does'nt do what you wanna do */
#define MAX_CHANNELS 6

/* interval in seconds between every interface update
   mostly is not needed to tweak this. if you do it,
   do it wise. */
#define UPDATE_INTERVAL 0.001 // 0.0006

/* filesystem */
#define MAX_PATH_SIZE 512

/* port on wich MuSE listens when in daemon mode */
#define LISTENPORT 6969

/* VUMeter tweaks
   be careful: if (SPACING>(PEAK_VOLUME/NUM_CELLS)) bad_things_happen(tm); */
#define PEAK_VOLUME 256
#define NUM_CELLS 20
#define SPACING 2
#define TALK_VOLUME 0.3

/* clipping values *do not change unless you know what you do*
   i assume a thresold of 0.9 */
#define MAX_SAMPLE 32766
#define CLIP 29489
#define CLIP_A 10738729 // ((MAX_SAMPLE-CLIP)*(MAX_SAMPLE-CLIP))
#define CLIP_B 26212 // (MAX_SAMPLE-2*CLIP)

#endif

==> MuSE-0.7pre1.tar.gz: MuSE-0.7pre1/generic.h <==
/* MuSE - Multiple Streaming Engine
 * Copyright (C) 2000-2002 Denis Roio aka jaromil <jaromil@dyne.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __GENERIC_H__
#define __GENERIC_H__

/* soundcard tweaks */
#define SAMPLE_RATE 44100 // 44100
#define BUF_SIZE 4608 // 1152 (mp3 default framesize) *2 (16bit) *2 (stereo)
#define PROCBUF_SIZE 8192 // mixer process buffers size
#define FRAGSIZE 0x000c // 4096 bytes
#define FRAGCOUNT 0x7fff // no limit

/* buffer settings (take care!) */
#define IN_BUFFER 32768
#define IN_DATATYPE short int
#define MIX_CHUNK 4608
#define PIPESIZE IN_BUFFER*4

/* mp3 channels - the standard interface can't be changed from here
   uhm... you'd better not touch this, i'm not sure it does what you wanna do */
#define MAX_CHANNELS 6

/* filesystem */
#define MAX_PATH_SIZE 512

/* talk button goes down that much */
#define TALK_VOLUME 0.3

/* clipping values (MOP patch) */
#define MOP_ADAPTIVE_VOL    1 
/* logging of k activation
   #define MOP_LOGGING         1 */
#ifdef MOP_ADAPTIVE_VOL
/* MOP_ADV_RETM  weight of the last k value in the computation of
                   the current k value (50-200 maybe a valid range) */
#define MOP_ADV_RETM       74.0
/* MOP_ADV_KARE  weight of the current clipped area in the computation
                   of the current k value (10-1000 ???) */
#define MOP_ADV_KARE      200.0
#endif


#endif
